# coding: utf-8
import pprint
import six
from enum import Enum



class PaymentMethodBrand:

    swagger_types = {
    
        'description': 'dict(str, str)',
        'gray_image_path': 'str',
        'id': 'int',
        'image_path': 'str',
        'name': 'dict(str, str)',
        'payment_method': 'int',
    }

    attribute_map = {
        'description': 'description','gray_image_path': 'grayImagePath','id': 'id','image_path': 'imagePath','name': 'name','payment_method': 'paymentMethod',
    }

    
    _description = None
    _gray_image_path = None
    _id = None
    _image_path = None
    _name = None
    _payment_method = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.description = kwargs.get('description', None)
        self.gray_image_path = kwargs.get('gray_image_path', None)
        self.id = kwargs.get('id', None)
        self.image_path = kwargs.get('image_path', None)
        self.name = kwargs.get('name', None)
        self.payment_method = kwargs.get('payment_method', None)
        

    
    @property
    def description(self):
        """Gets the description of this PaymentMethodBrand.

            The localized description of the object.

        :return: The description of this PaymentMethodBrand.
        :rtype: dict(str, str)
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this PaymentMethodBrand.

            The localized description of the object.

        :param description: The description of this PaymentMethodBrand.
        :type: dict(str, str)
        """

        self._description = description
    
    @property
    def gray_image_path(self):
        """Gets the gray_image_path of this PaymentMethodBrand.

            

        :return: The gray_image_path of this PaymentMethodBrand.
        :rtype: str
        """
        return self._gray_image_path

    @gray_image_path.setter
    def gray_image_path(self, gray_image_path):
        """Sets the gray_image_path of this PaymentMethodBrand.

            

        :param gray_image_path: The gray_image_path of this PaymentMethodBrand.
        :type: str
        """

        self._gray_image_path = gray_image_path
    
    @property
    def id(self):
        """Gets the id of this PaymentMethodBrand.

            A unique identifier for the object.

        :return: The id of this PaymentMethodBrand.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PaymentMethodBrand.

            A unique identifier for the object.

        :param id: The id of this PaymentMethodBrand.
        :type: int
        """

        self._id = id
    
    @property
    def image_path(self):
        """Gets the image_path of this PaymentMethodBrand.

            

        :return: The image_path of this PaymentMethodBrand.
        :rtype: str
        """
        return self._image_path

    @image_path.setter
    def image_path(self, image_path):
        """Sets the image_path of this PaymentMethodBrand.

            

        :param image_path: The image_path of this PaymentMethodBrand.
        :type: str
        """

        self._image_path = image_path
    
    @property
    def name(self):
        """Gets the name of this PaymentMethodBrand.

            The localized name of the object.

        :return: The name of this PaymentMethodBrand.
        :rtype: dict(str, str)
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PaymentMethodBrand.

            The localized name of the object.

        :param name: The name of this PaymentMethodBrand.
        :type: dict(str, str)
        """

        self._name = name
    
    @property
    def payment_method(self):
        """Gets the payment_method of this PaymentMethodBrand.

            

        :return: The payment_method of this PaymentMethodBrand.
        :rtype: int
        """
        return self._payment_method

    @payment_method.setter
    def payment_method(self, payment_method):
        """Sets the payment_method of this PaymentMethodBrand.

            

        :param payment_method: The payment_method of this PaymentMethodBrand.
        :type: int
        """

        self._payment_method = payment_method
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(PaymentMethodBrand, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, PaymentMethodBrand):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum
from . import AbstractShopifySubscriptionProductUpdate


class ShopifySubscriptionProductCreate(AbstractShopifySubscriptionProductUpdate):

    swagger_types = {
    
        'product_id': 'str',
        'product_variant_id': 'str',
        'shop': 'int',
    }

    attribute_map = {
        'product_id': 'productId','product_variant_id': 'productVariantId','shop': 'shop',
    }

    
    _product_id = None
    _product_variant_id = None
    _shop = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.product_id = kwargs.get('product_id')

        self.product_variant_id = kwargs.get('product_variant_id')

        self.shop = kwargs.get('shop')

        super().__init__(**kwargs)
        self.swagger_types.update(super().swagger_types)
        self.attribute_map.update(super().attribute_map)

    
    @property
    def product_id(self):
        """Gets the product_id of this ShopifySubscriptionProductCreate.

            The ID of the Shopify product that is enabled to be ordered as subscription.

        :return: The product_id of this ShopifySubscriptionProductCreate.
        :rtype: str
        """
        return self._product_id

    @product_id.setter
    def product_id(self, product_id):
        """Sets the product_id of this ShopifySubscriptionProductCreate.

            The ID of the Shopify product that is enabled to be ordered as subscription.

        :param product_id: The product_id of this ShopifySubscriptionProductCreate.
        :type: str
        """
        if product_id is None:
            raise ValueError("Invalid value for `product_id`, must not be `None`")

        self._product_id = product_id
    
    @property
    def product_variant_id(self):
        """Gets the product_variant_id of this ShopifySubscriptionProductCreate.

            

        :return: The product_variant_id of this ShopifySubscriptionProductCreate.
        :rtype: str
        """
        return self._product_variant_id

    @product_variant_id.setter
    def product_variant_id(self, product_variant_id):
        """Sets the product_variant_id of this ShopifySubscriptionProductCreate.

            

        :param product_variant_id: The product_variant_id of this ShopifySubscriptionProductCreate.
        :type: str
        """
        if product_variant_id is None:
            raise ValueError("Invalid value for `product_variant_id`, must not be `None`")

        self._product_variant_id = product_variant_id
    
    @property
    def shop(self):
        """Gets the shop of this ShopifySubscriptionProductCreate.

            

        :return: The shop of this ShopifySubscriptionProductCreate.
        :rtype: int
        """
        return self._shop

    @shop.setter
    def shop(self, shop):
        """Sets the shop of this ShopifySubscriptionProductCreate.

            

        :param shop: The shop of this ShopifySubscriptionProductCreate.
        :type: int
        """
        if shop is None:
            raise ValueError("Invalid value for `shop`, must not be `None`")

        self._shop = shop
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(ShopifySubscriptionProductCreate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, ShopifySubscriptionProductCreate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class ShopifySubscriptionUpdateAddressesRequest:

    swagger_types = {
    
        'billing_address': 'ShopifySubscriptionAddressCreate',
        'id': 'int',
        'shipping_address': 'ShopifySubscriptionAddressCreate',
    }

    attribute_map = {
        'billing_address': 'billingAddress','id': 'id','shipping_address': 'shippingAddress',
    }

    
    _billing_address = None
    _id = None
    _shipping_address = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.billing_address = kwargs.get('billing_address', None)
        self.id = kwargs.get('id', None)
        self.shipping_address = kwargs.get('shipping_address', None)
        

    
    @property
    def billing_address(self):
        """Gets the billing_address of this ShopifySubscriptionUpdateAddressesRequest.

            

        :return: The billing_address of this ShopifySubscriptionUpdateAddressesRequest.
        :rtype: ShopifySubscriptionAddressCreate
        """
        return self._billing_address

    @billing_address.setter
    def billing_address(self, billing_address):
        """Sets the billing_address of this ShopifySubscriptionUpdateAddressesRequest.

            

        :param billing_address: The billing_address of this ShopifySubscriptionUpdateAddressesRequest.
        :type: ShopifySubscriptionAddressCreate
        """

        self._billing_address = billing_address
    
    @property
    def id(self):
        """Gets the id of this ShopifySubscriptionUpdateAddressesRequest.

            

        :return: The id of this ShopifySubscriptionUpdateAddressesRequest.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ShopifySubscriptionUpdateAddressesRequest.

            

        :param id: The id of this ShopifySubscriptionUpdateAddressesRequest.
        :type: int
        """

        self._id = id
    
    @property
    def shipping_address(self):
        """Gets the shipping_address of this ShopifySubscriptionUpdateAddressesRequest.

            

        :return: The shipping_address of this ShopifySubscriptionUpdateAddressesRequest.
        :rtype: ShopifySubscriptionAddressCreate
        """
        return self._shipping_address

    @shipping_address.setter
    def shipping_address(self, shipping_address):
        """Sets the shipping_address of this ShopifySubscriptionUpdateAddressesRequest.

            

        :param shipping_address: The shipping_address of this ShopifySubscriptionUpdateAddressesRequest.
        :type: ShopifySubscriptionAddressCreate
        """

        self._shipping_address = shipping_address
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(ShopifySubscriptionUpdateAddressesRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, ShopifySubscriptionUpdateAddressesRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8

from __future__ import absolute_import

import six
import re

from wallee.api_client import ApiClient

class MerticUsageServiceApi:

    def __init__(self, configuration):
        self.api_client = ApiClient(configuration=configuration)

    def calculate(self, space_id, start, end, **kwargs):
        """Calculate

        Calculates the consumed resources for the given space and time range.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True.
        
        >>> thread = api.calculate(space_id, start, end, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param datetime start: The start date from which on the consumed units should be returned from. (required)
        :param datetime end: The end date to which the consumed units should be returned to. The end date is not included in the result. (required)
        :return: list[MetricUsage]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        
        kwargs['request_timeout'] = self.api_client.configuration.request_timeout
        if kwargs.get('async_req'):
            return self.calculate_with_http_info(space_id, start, end, **kwargs)
        else:
            (data) = self.calculate_with_http_info(space_id, start, end, **kwargs)
            return data

    def calculate_with_http_info(self, space_id, start, end, **kwargs):
        """Calculate

        Calculates the consumed resources for the given space and time range.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True.
        
        >>> thread = api.calculate_with_http_info(space_id, start, end, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int space_id:  (required)
        :param datetime start: The start date from which on the consumed units should be returned from. (required)
        :param datetime end: The end date to which the consumed units should be returned to. The end date is not included in the result. (required)
        :return: list[MetricUsage]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['space_id', 'start', 'end']
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method calculate" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'space_id' is set
        if ('space_id' not in params or
                params['space_id'] is None):
            raise ValueError("Missing the required parameter `space_id` when calling `calculate`")
        # verify the required parameter 'start' is set
        if ('start' not in params or
                params['start'] is None):
            raise ValueError("Missing the required parameter `start` when calling `calculate`")
        # verify the required parameter 'end' is set
        if ('end' not in params or
                params['end'] is None):
            raise ValueError("Missing the required parameter `end` when calling `calculate`")

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'space_id' in params:
            query_params.append(('spaceId', params['space_id']))
        if 'start' in params:
            query_params.append(('start', params['start']))
        if 'end' in params:
            query_params.append(('end', params['end']))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json;charset=utf-8'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(
            ['*/*'])

        # Authentication setting
        auth_settings = []

        return self.api_client.call_api(
            '/mertic-usage/calculate', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[MetricUsage]',
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('request_timeout'),
            collection_formats=collection_formats)
